Class: Google::Cloud::GkeMultiCloud::V1::AwsNodePool Deprecated

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb

Overview

Deprecated.

This message is deprecated and may be removed in the next major version update.

An Anthos node pool running on AWS.

Defined Under Namespace

Modules: State Classes: AnnotationsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#annotations::Google::Protobuf::Map{::String => ::String}

Returns Optional. Annotations on the node pool.

This field has the same restrictions as Kubernetes annotations. The total size of all keys and values combined is limited to 256k. Key can have 2 segments: prefix (optional) and name (required), separated by a slash (/). Prefix must be a DNS subdomain. Name must be 63 characters or less, begin and end with alphanumerics, with dashes (-), underscores (_), dots (.), and alphanumerics between.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Annotations on the node pool.

    This field has the same restrictions as Kubernetes annotations. The total size of all keys and values combined is limited to 256k. Key can have 2 segments: prefix (optional) and name (required), separated by a slash (/). Prefix must be a DNS subdomain. Name must be 63 characters or less, begin and end with alphanumerics, with dashes (-), underscores (_), dots (.), and alphanumerics between.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#autoscaling::Google::Cloud::GkeMultiCloud::V1::AwsNodePoolAutoscaling

Returns Required. Autoscaler configuration for this node pool.

Returns:



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#config::Google::Cloud::GkeMultiCloud::V1::AwsNodeConfig

Returns Required. The configuration of the node pool.

Returns:



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which this node pool was created.

Returns:



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#errors::Array<::Google::Cloud::GkeMultiCloud::V1::AwsNodePoolError> (readonly)

Returns Output only. A set of errors found in the node pool.

Returns:



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#etag::String

Returns Allows clients to perform consistent read-modify-writes through optimistic concurrency control.

Can be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.

Returns:

  • (::String)

    Allows clients to perform consistent read-modify-writes through optimistic concurrency control.

    Can be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#kubelet_config::Google::Cloud::GkeMultiCloud::V1::NodeKubeletConfig

Returns Optional. Node kubelet configs.

Returns:



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#management::Google::Cloud::GkeMultiCloud::V1::AwsNodeManagement

Returns Optional. The Management configuration for this node pool.

Returns:



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#max_pods_constraint::Google::Cloud::GkeMultiCloud::V1::MaxPodsConstraint

Returns Required. The constraint on the maximum number of pods that can be run simultaneously on a node in the node pool.

Returns:



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#name::String

Returns The name of this resource.

Node pool names are formatted as projects/<project-number>/locations/<region>/awsClusters/<cluster-id>/awsNodePools/<node-pool-id>.

For more details on Google Cloud resource names, see Resource Names.

Returns:

  • (::String)

    The name of this resource.

    Node pool names are formatted as projects/<project-number>/locations/<region>/awsClusters/<cluster-id>/awsNodePools/<node-pool-id>.

    For more details on Google Cloud resource names, see Resource Names



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#reconciling::Boolean (readonly)

Returns Output only. If set, there are currently changes in flight to the node pool.

Returns:

  • (::Boolean)

    Output only. If set, there are currently changes in flight to the node pool.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#state::Google::Cloud::GkeMultiCloud::V1::AwsNodePool::State (readonly)

Returns Output only. The lifecycle state of the node pool.

Returns:



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#subnet_id::String

Returns Required. The subnet where the node pool node run.

Returns:

  • (::String)

    Required. The subnet where the node pool node run.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#uid::String (readonly)

Returns Output only. A globally unique identifier for the node pool.

Returns:

  • (::String)

    Output only. A globally unique identifier for the node pool.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#update_settings::Google::Cloud::GkeMultiCloud::V1::UpdateSettings

Returns Optional. Update settings control the speed and disruption of the update.

Returns:



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time at which this node pool was last updated.

Returns:



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end

#version::String

Returns Required. The Kubernetes version to run on this node pool (e.g. 1.19.10-gke.1000).

You can list all supported versions on a given Google Cloud region by calling GetAwsServerConfig.

Returns:

  • (::String)

    Required. The Kubernetes version to run on this node pool (e.g. 1.19.10-gke.1000).

    You can list all supported versions on a given Google Cloud region by calling GetAwsServerConfig.



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'proto_docs/google/cloud/gkemulticloud/v1/aws_resources.rb', line 476

class AwsNodePool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The lifecycle state of the node pool.
  module State
    # Not set.
    STATE_UNSPECIFIED = 0

    # The PROVISIONING state indicates the node pool is being created.
    PROVISIONING = 1

    # The RUNNING state indicates the node pool has been created
    # and is fully usable.
    RUNNING = 2

    # The RECONCILING state indicates that the node pool is being reconciled.
    RECONCILING = 3

    # The STOPPING state indicates the node pool is being deleted.
    STOPPING = 4

    # The ERROR state indicates the node pool is in a broken unrecoverable
    # state.
    ERROR = 5

    # The DEGRADED state indicates the node pool requires user action to
    # restore full functionality.
    DEGRADED = 6
  end
end