Class: Google::Cloud::GkeMultiCloud::V1::GetAzureJsonWebKeysRequest Deprecated
- Inherits:
-
Object
- Object
- Google::Cloud::GkeMultiCloud::V1::GetAzureJsonWebKeysRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkemulticloud/v1/azure_service.rb
Overview
Deprecated.
This message is deprecated and may be removed in the next major version update.
GetAzureJsonWebKeysRequest gets the public component of the keys used by the cluster to sign token requests. This will be the jwks_uri for the discover document returned by getOpenIDConfig. See the OpenID Connect Discovery 1.0 specification for details.
Instance Attribute Summary collapse
-
#azure_cluster ⇒ ::String
Required.
Instance Attribute Details
#azure_cluster ⇒ ::String
Returns Required. The AzureCluster, which owns the JsonWebKeys.
Format:
projects/<project-id>/locations/<region>/azureClusters/<cluster-id>.
397 398 399 400 |
# File 'proto_docs/google/cloud/gkemulticloud/v1/azure_service.rb', line 397 class GetAzureJsonWebKeysRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |